---
title: <span class="badge builder"></span> FillConfig
---
# <span class="badge builder"></span> FillConfig

## Constructor

```python
FillConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.FillConfig
```

### <span class="badge object-method"></span> fill_below_to

```python
def fill_below_to(fill_below_to: str) -> typing.Self
```

### <span class="badge object-method"></span> fill_color

```python
def fill_color(fill_color: str) -> typing.Self
```

### <span class="badge object-method"></span> fill_opacity

```python
def fill_opacity(fill_opacity: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [FillConfig](./object-FillConfig.md)
